<p>
  <img src="https://raw.githubusercontent.com/tukaan/.github/master/assets/tukaan.png" alt="Tukaan logo" width="130px" align="left">
  <h1>Tukaan</h1>
  Tukaan is a Python toolkit for creating cross-platform GUI applications
</p>
</br>
<div align="center">

  [![tukaan.github.io](https://img.shields.io/badge/Website-tukaan.github.io-%23ec9f30)](https://tukaan.github.io)
  [![Downloads](https://static.pepy.tech/badge/tukaan)](https://pypi.org/project/tukaan)
  [![License: MIT](https://img.shields.io/badge/License-MIT-%23aaffaa.svg)](https://opensource.org/licenses/MIT)
  [![Code style: black](https://img.shields.io/badge/Code%20style-black-%23272727.svg)](https://github.com/psf/black)
  [![#StandWithUkraine](https://raw.githubusercontent.com/vshymanskyy/StandWithUkraine/main/badges/StandWithUkraine.svg)](https://www.standwithukraine.how/)
  
</div>
</br>

## We are looking for contributors 😍
Tukaan is already one and a half years old, but it is still in alpha state. Developing such a toolkit takes a lot of work, so the more of us there are, the better it will be, and the sooner we can release a stable version.

See [CONTRIBUTING.md](CONTRIBUTING.md) for more.

---

## What is Tukaan?

Tukaan is a GUI toolkit based on Tcl/Tk. Yeah, that’s the same thing that powers Tkinter, but don’t worry, Tukaan is far not as bad as Tkinter.

It is designed to be a modern and pythonic framework that provides everything you need in a GUI application, without having to install all sorts of third-party extensions to accomplish a basic task.


### 🔶 Tukaan is powerful
With Tukaan you can build whatever you want. It includes a wide variety of widgets, from basic things like tooltips to advanced megawidgets, dozens of options for integration with the operating system, and a bunch of other things that make creating an application even more convenient.

### 🔶 Tukaan is modern
Tukaan does not try to mimic the look and feel of Motif or Windows 95. You can create interfaces that look native on Windows, macOS and Plasma, or theme it however you like, so the users might actually want to use it. Unlike Tkinter, it has most of the features you expect from a GUI toolkit in the 21st century. No need to spend hours browsing random forums to figure out how to load a custom font file, such basic things are built in already!

### 🔶 Tukaan is intuitive
Tukaan is pythonic and intuitive, so you don’t necessarily have to look up the documentation every time, you can figure it out for yourself. However, keep in mind that it is not recommended for complete beginners. You need some knowledge of Python, and some sort of experience in GUI programming can also come handy, although that’s not required.

[Get started with Tukaan!](https://tukaan.github.io/docs)

## FAQ

#### Why did you name this project `Tukaan`?
Tk's logo is a feather, so I wanted to name the project after a bird with `T` and `K` in its name. So I came up with `tukán` (means toucan in english). However Github doesn't allow non-english characters in repository names, so I had to simplify it to `tukaan`.

#### How do you pronounce `Tukaan`?
`tukaːn`


## Credits
- Aldo Buratti - [`extrafont`](https://sourceforge.net/projects/irrational-numbers/files/extrafont/)
- Inspiration
  - [Akuli/Teek](https://github.com/Akuli/teek)
  - [UnsignedArduino/TkZero](https://github.com/UnsignedArduino/TkZero)
  - [lawsie/guizero](https://github.com/lawsie/guizero)
  - Logo design inspired by [Tajulislam12's design on Dribbble](https://dribbble.com/shots/14487668-toucan-logo-design-Icon)
